# Flask-GFM
[![PyPI version](https://badge.fury.io/py/Flask-GFM.svg)](https://badge.fury.io/py/Flask-GFM)

GitHub Flavored Markdown jinja2 extension for Flask

## Installation

    $ pip install Flask-GFM
